==> mingw-w64-python-fastapi-0.125.0-1.src.tar.zst: fastapi-0.125.0/docs/pt/docs/deployment/index.md <==
# Implantação { #deployment }

Implantar uma aplicação **FastAPI** é relativamente fácil.

## O que significa Implantação { #what-does-deployment-mean }

Implantar uma aplicação significa executar as etapas necessárias para torná-la disponível para os usuários.

Para uma **web API**, isso normalmente envolve colocá-la em uma **máquina remota**, com um **programa de servidor** que ofereça bom desempenho, estabilidade, etc., de modo que seus **usuários** possam **acessar** a aplicação com eficiência e sem interrupções ou problemas.

Isso contrasta com as fases de **desenvolvimento**, em que você está constantemente alterando o código, quebrando e consertando, parando e reiniciando o servidor de desenvolvimento, etc.

## Estratégias de Implantação { #deployment-strategies }

Há várias maneiras de fazer isso, dependendo do seu caso de uso específico e das ferramentas que você utiliza.

Você pode **implantar um servidor** por conta própria usando uma combinação de ferramentas, pode usar um **serviço em nuvem** que faça parte do trabalho por você, entre outras opções.

Por exemplo, nós, a equipe por trás do FastAPI, criamos <a href="https://fastapicloud.com" class="external-link" target="_blank">**FastAPI Cloud**</a>, para tornar a implantação de aplicações FastAPI na nuvem o mais simples possível, com a mesma experiência de desenvolvimento de trabalhar com o FastAPI.

Vou mostrar alguns dos principais conceitos que você provavelmente deve ter em mente ao implantar uma aplicação **FastAPI** (embora a maior parte se aplique a qualquer outro tipo de aplicação web).

Você verá mais detalhes para ter em mente e algumas das técnicas para fazer isso nas próximas seções. ✨

==> mingw-w64-python-fastapi-0.132.0-1.src.tar.zst: fastapi-0.132.0/docs/pt/docs/deployment/index.md <==
# Implantação { #deployment }

Implantar uma aplicação **FastAPI** é relativamente fácil.

## O que significa Implantação { #what-does-deployment-mean }

**Implantar** uma aplicação significa executar as etapas necessárias para torná-la **disponível para os usuários**.

Para uma **web API**, isso normalmente envolve colocá-la em uma **máquina remota**, com um **programa de servidor** que ofereça bom desempenho, estabilidade, etc., de modo que seus **usuários** possam **acessar** a aplicação com eficiência e sem interrupções ou problemas.

Isso contrasta com as fases de **desenvolvimento**, em que você está constantemente alterando o código, quebrando e consertando, parando e reiniciando o servidor de desenvolvimento, etc.

## Estratégias de Implantação { #deployment-strategies }

Há várias maneiras de fazer isso, dependendo do seu caso de uso específico e das ferramentas que você utiliza.

Você pode **implantar um servidor** por conta própria usando uma combinação de ferramentas, pode usar um **serviço em nuvem** que faça parte do trabalho por você, entre outras opções.

Por exemplo, nós, a equipe por trás do FastAPI, criamos <a href="https://fastapicloud.com" class="external-link" target="_blank">**FastAPI Cloud**</a>, para tornar a implantação de aplicações FastAPI na nuvem o mais simples possível, com a mesma experiência de desenvolvimento de trabalhar com o FastAPI.

Vou mostrar alguns dos principais conceitos que você provavelmente deve ter em mente ao implantar uma aplicação **FastAPI** (embora a maior parte se aplique a qualquer outro tipo de aplicação web).

Você verá mais detalhes para ter em mente e algumas das técnicas para fazer isso nas próximas seções. ✨
